# XChainPy2 THORChain Query

This module performs the following functions:
- Get the estimated quote for a swap / LP add / Savers
- Check the status of a transaction

### Documentation

👉 https://xchainpy2.readthedocs.io/en/latest/packages/xchainpy2_thorchain_query.html

